==> react-jsonschema-form-ui2-1.0.2.tgz: package/es/forms/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import _ from "lodash";
import React from "react";
import Form from "react-jsonschema-form";

var SchemaForm = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(SchemaForm, _React$Component);

  function SchemaForm() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "form", React.createRef());

    return _this;
  }

  var _proto = SchemaForm.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var formContext = _extends({}, this.props.formContext || {});

    return /*#__PURE__*/React.createElement(Form, _extends({
      ref: function ref(form) {
        _this2.form.current = form;
      }
    }, this.props, {
      formContext: _extends({}, formContext, {
        form: this.form
      })
    }));
  };

  _proto.renderForm = function renderForm(props) {
    return /*#__PURE__*/React.createElement("div", null, "HI");
  };

  return SchemaForm;
}(React.Component);

export default SchemaForm;

==> react-jsonschema-form-ui2-2.0.1.tgz: package/es/forms/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import _ from "lodash";
import React from "react"; // import Form from "@rjsf/core";

import Form from "@rjsf/bootstrap-4";
import CodeReader from "./../fields/ReactScannerField/scanner";

var SchemaForm = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(SchemaForm, _React$Component);

  function SchemaForm() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "form", React.createRef());

    return _this;
  }

  var _proto = SchemaForm.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var formContext = _extends({}, this.props.formContext || {});

    return /*#__PURE__*/React.createElement(Form, _extends({
      ref: function ref(form) {
        _this2.form.current = form;
      }
    }, this.props, {
      formContext: _extends({}, formContext, {
        form: this.form
      })
    }));
  };

  _proto.renderForm = function renderForm(props) {
    return /*#__PURE__*/React.createElement("div", null, "HI");
  };

  return SchemaForm;
}(React.Component);

export default SchemaForm;
